@@ -344,10 +344,10 @@ static int fuzzerLoadOneRule(
       memset(pRule, 0, sizeof(*pRule));
       pRule->zFrom = pRule->zTo;
       pRule->zFrom += nTo + 1;
-      pRule->nFrom = nFrom;
+      pRule->nFrom = (fuzzer_len)nFrom;
       memcpy(pRule->zFrom, zFrom, nFrom+1);
       memcpy(pRule->zTo, zTo, nTo+1);
-      pRule->nTo = nTo;
+      pRule->nTo = (fuzzer_len)nTo;
       pRule->rCost = nCost;
       pRule->iRuleset = (int)iRuleset;
     }
@@ -447,19 +447,19 @@ static int fuzzerLoadRules(
 **     `mno`   becomes   mno
 */
 static char *fuzzerDequote(const char *zIn){
-  int nIn;                        /* Size of input string, in bytes */
+  size_t nIn;                     /* Size of input string, in bytes */
   char *zOut;                     /* Output (dequoted) string */
 
-  nIn = (int)strlen(zIn);
+  nIn = strlen(zIn);
   zOut = sqlite3_malloc(nIn+1);
   if( zOut ){
     char q = zIn[0];              /* Quote character (if any ) */
 
     if( q!='[' && q!= '\'' && q!='"' && q!='`' ){
-      memcpy(zOut, zIn, nIn+1);
+      memcpy(zOut, zIn, (size_t)(nIn+1));
     }else{
-      int iOut = 0;               /* Index of next byte to write to output */
-      int iIn;                    /* Index of next byte to read from input */
+      size_t iOut = 0;            /* Index of next byte to write to output */
+      size_t iIn;                 /* Index of next byte to read from input */
 
       if( q=='[' ) q = ']';
       for(iIn=1; iIn<nIn; iIn++){
@@ -467,7 +467,7 @@ static char *fuzzerDequote(const char *zIn){
         zOut[iOut++] = zIn[iIn];
       }
     }
-    assert( (int)strlen(zOut)<=nIn );
+    assert( strlen(zOut)<=nIn );
   }
   return zOut;
 }
@@ -513,9 +513,9 @@ static int fuzzerConnect(
     );
     rc = SQLITE_ERROR;
   }else{
-    int nModule;                  /* Length of zModule, in bytes */
+    size_t nModule;        /* Length of zModule, in bytes */
 
-    nModule = (int)strlen(zModule);
+    nModule = strlen(zModule);
     pNew = sqlite3_malloc( sizeof(*pNew) + nModule + 1);
     if( pNew==0 ){
       rc = SQLITE_NOMEM;
@@ -524,7 +524,7 @@ static int fuzzerConnect(
 
       memset(pNew, 0, sizeof(*pNew));
       pNew->zClassName = (char*)&pNew[1];
-      memcpy(pNew->zClassName, zModule, nModule+1);
+      memcpy(pNew->zClassName, zModule, (size_t)(nModule+1));
 
       zTab = fuzzerDequote(argv[3]);
       if( zTab==0 ){
@@ -872,7 +872,7 @@ static fuzzer_stem *fuzzerNewStem(
   fuzzer_rule *pRule;
   unsigned int h;
 
-  pNew = sqlite3_malloc( sizeof(*pNew) + (int)strlen(zWord) + 1 );
+  pNew = sqlite3_malloc( sizeof(*pNew) + strlen(zWord) + 1 );
   if( pNew==0 ) return 0;
   memset(pNew, 0, sizeof(*pNew));
   pNew->zBasis = (char*)&pNew[1];
